@@ -1,2 +1,2 @@
-from .cobertura import Cobertura  # noqa
+from .cobertura import Cobertura, CoberturaDiff  # noqa
 from .reporters import TextReporter, TextReporterDelta  # noqa
